==> blancoAntTask-0.4.0-src.zip: blancoAntTask/blanco/main/blanco/sample/task/BlancoAntTaskSampleTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoAntTaskSample]̃NX
 */
package blanco.sample.task;

import java.math.BigDecimal;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.sample.task.valueobject.BlancoAntTaskSampleBatchProcessInput;

/**
 * Apache Ant^XN [BlancoAntTaskSample]̃NXB
 *
 * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.sample.task]BlancoAntTaskSampleBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoanttasksample&quot; classname=&quot;blanco.sample.task.BlancoAntTaskSampleTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoAntTaskSampleTask extends Task {
    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected BlancoAntTaskSampleBatchProcessInput fInput = new BlancoAntTaskSampleBatchProcessInput();

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr1Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr2Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr3Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr4Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr5Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr6Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr7Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr8Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr9Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr10Processed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[attr1]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * iK{j<br>
     *
     * @param arg Zbgl
     */
    public void setAttr1(final String arg) {
        fInput.setAttr1(arg);
        fIsFieldAttr1Processed = true;
    }

    /**
     * Ant^XN[attr1]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * iK{j<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr1() {
        return fInput.getAttr1();
    }

    /**
     * Ant^XN[attr2]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * blanco:string<br>
     *
     * @param arg Zbgl
     */
    public void setAttr2(final String arg) {
        fInput.setAttr2(arg);
        fIsFieldAttr2Processed = true;
    }

    /**
     * Ant^XN[attr2]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * blanco:string<br>
     * ftHgl[ftHg]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr2() {
        return fInput.getAttr2();
    }

    /**
     * Ant^XN[attr3]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * (int)(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr3(final String arg) {
        try {
            fInput.setAttr3(Integer.parseInt(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr3]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr3Processed = true;
    }

    /**
     * Ant^XN[attr3]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * (int)(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr3() {
        return String.valueOf(fInput.getAttr3());
    }

    /**
     * Ant^XN[attr4]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * blanco:int<br>
     *
     * @param arg Zbgl
     */
    public void setAttr4(final String arg) {
        try {
            fInput.setAttr4(Integer.parseInt(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr4]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr4Processed = true;
    }

    /**
     * Ant^XN[attr4]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * blanco:int<br>
     * ftHgl[10]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr4() {
        return String.valueOf(fInput.getAttr4());
    }

    /**
     * Ant^XN[attr5]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * (long)(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr5(final String arg) {
        try {
            fInput.setAttr5(Long.parseLong(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr5]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr5Processed = true;
    }

    /**
     * Ant^XN[attr5]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * (long)(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr5() {
        return String.valueOf(fInput.getAttr5());
    }

    /**
     * Ant^XN[attr6]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * blanco:long<br>
     *
     * @param arg Zbgl
     */
    public void setAttr6(final String arg) {
        try {
            fInput.setAttr6(Long.parseLong(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr6]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr6Processed = true;
    }

    /**
     * Ant^XN[attr6]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * blanco:long<br>
     * ftHgl[100]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr6() {
        return String.valueOf(fInput.getAttr6());
    }

    /**
     * Ant^XN[attr7]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 7<br>
     * (decimal)(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr7(final String arg) {
        try {
            fInput.setAttr7(new BigDecimal(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr7]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr7Processed = true;
    }

    /**
     * Ant^XN[attr7]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 7<br>
     * (decimal)(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr7() {
        return fInput.getAttr7().toString();
    }

    /**
     * Ant^XN[attr8]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 8<br>
     * (decimal)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr8(final String arg) {
        try {
            fInput.setAttr8(new BigDecimal(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr8]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr8Processed = true;
    }

    /**
     * Ant^XN[attr8]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 8<br>
     * (decimal)<br>
     * ftHgl[123.456]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr8() {
        return fInput.getAttr8().toString();
    }

    /**
     * Ant^XN[attr9]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 9<br>
     * ^U(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr9(final boolean arg) {
        fInput.setAttr9(arg);
        fIsFieldAttr9Processed = true;
    }

    /**
     * Ant^XN[attr9]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 9<br>
     * ^U(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getAttr9() {
        return fInput.getAttr9();
    }

    /**
     * Ant^XN[attr10]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 10<br>
     * blanco:boolean<br>
     *
     * @param arg Zbgl
     */
    public void setAttr10(final boolean arg) {
        fInput.setAttr10(arg);
        fIsFieldAttr10Processed = true;
    }

    /**
     * Ant^XN[attr10]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 10<br>
     * blanco:boolean<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getAttr10() {
        return fInput.getAttr10();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoAntTaskSampleTask begin.");

        // ڔԍ[1]AAgr[g[attr1]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr1Processed == false) {
            throw new BuildException("K{Agr[g[attr1]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[3]AAgr[g[attr3]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr3Processed == false) {
            throw new BuildException("K{Agr[g[attr3]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[5]AAgr[g[attr5]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr5Processed == false) {
            throw new BuildException("K{Agr[g[attr5]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[7]AAgr[g[attr7]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr7Processed == false) {
            throw new BuildException("K{Agr[g[attr7]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[9]AAgr[g[attr9]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr9Processed == false) {
            throw new BuildException("K{Agr[g[attr9]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- attr1:[" + getAttr1() + "]");
            System.out.println("- attr2:[" + getAttr2() + "]");
            System.out.println("- attr3:[" + getAttr3() + "]");
            System.out.println("- attr4:[" + getAttr4() + "]");
            System.out.println("- attr5:[" + getAttr5() + "]");
            System.out.println("- attr6:[" + getAttr6() + "]");
            System.out.println("- attr7:[" + getAttr7() + "]");
            System.out.println("- attr8:[" + getAttr8() + "]");
            System.out.println("- attr9:[" + getAttr9() + "]");
            System.out.println("- attr10:[" + getAttr10() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            if (new BlancoAntTaskSampleBatchProcess().execute(fInput) != BlancoAntTaskSampleBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoAntTask-0.6.0-src.zip: blancoAntTask/blanco/main/blanco/sample/task/BlancoAntTaskSampleTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoAntTaskSample]̃NX
 */
package blanco.sample.task;

import java.math.BigDecimal;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.sample.task.valueobject.BlancoAntTaskSampleProcessInput;

/**
 * Apache Ant^XN [BlancoAntTaskSample]̃NXB
 *
 * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.sample.task]BlancoAntTaskSampleBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoanttasksample&quot; classname=&quot;blanco.sample.task.BlancoAntTaskSampleTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoAntTaskSampleTask extends Task {
    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected BlancoAntTaskSampleProcessInput fInput = new BlancoAntTaskSampleProcessInput();

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr1Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr2Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr3Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr4Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr5Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr6Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr7Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr8Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr9Processed = false;

    /**
     * ̃NX͒PɃTvłBۂ̓ɂ͗p܂B
     */
    protected boolean fIsFieldAttr10Processed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[attr1]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * iK{j<br>
     *
     * @param arg Zbgl
     */
    public void setAttr1(final String arg) {
        fInput.setAttr1(arg);
        fIsFieldAttr1Processed = true;
    }

    /**
     * Ant^XN[attr1]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * iK{j<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr1() {
        return fInput.getAttr1();
    }

    /**
     * Ant^XN[attr2]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * blanco:string<br>
     *
     * @param arg Zbgl
     */
    public void setAttr2(final String arg) {
        fInput.setAttr2(arg);
        fIsFieldAttr2Processed = true;
    }

    /**
     * Ant^XN[attr2]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * blanco:string<br>
     * ftHgl[ftHg]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr2() {
        return fInput.getAttr2();
    }

    /**
     * Ant^XN[attr3]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * (int)(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr3(final String arg) {
        try {
            fInput.setAttr3(Integer.parseInt(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr3]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr3Processed = true;
    }

    /**
     * Ant^XN[attr3]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * (int)(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr3() {
        return String.valueOf(fInput.getAttr3());
    }

    /**
     * Ant^XN[attr4]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * blanco:int<br>
     *
     * @param arg Zbgl
     */
    public void setAttr4(final String arg) {
        try {
            fInput.setAttr4(Integer.parseInt(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr4]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr4Processed = true;
    }

    /**
     * Ant^XN[attr4]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * blanco:int<br>
     * ftHgl[10]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr4() {
        return String.valueOf(fInput.getAttr4());
    }

    /**
     * Ant^XN[attr5]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * (long)(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr5(final String arg) {
        try {
            fInput.setAttr5(Long.parseLong(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr5]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr5Processed = true;
    }

    /**
     * Ant^XN[attr5]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * (long)(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr5() {
        return String.valueOf(fInput.getAttr5());
    }

    /**
     * Ant^XN[attr6]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * blanco:long<br>
     *
     * @param arg Zbgl
     */
    public void setAttr6(final String arg) {
        try {
            fInput.setAttr6(Long.parseLong(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr6]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr6Processed = true;
    }

    /**
     * Ant^XN[attr6]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * blanco:long<br>
     * ftHgl[100]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr6() {
        return String.valueOf(fInput.getAttr6());
    }

    /**
     * Ant^XN[attr7]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 7<br>
     * (decimal)(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr7(final String arg) {
        try {
            fInput.setAttr7(new BigDecimal(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr7]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr7Processed = true;
    }

    /**
     * Ant^XN[attr7]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 7<br>
     * (decimal)(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr7() {
        return fInput.getAttr7().toString();
    }

    /**
     * Ant^XN[attr8]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 8<br>
     * (decimal)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr8(final String arg) {
        try {
            fInput.setAttr8(new BigDecimal(arg));
        } catch (NumberFormatException e) {
            throw new IllegalArgumentException("Ant^XN[attr8]Agr[gɗ^ꂽl̐l͂Ɏs܂B" + e.toString());
        }
        fIsFieldAttr8Processed = true;
    }

    /**
     * Ant^XN[attr8]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 8<br>
     * (decimal)<br>
     * ftHgl[123.456]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getAttr8() {
        return fInput.getAttr8().toString();
    }

    /**
     * Ant^XN[attr9]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 9<br>
     * ^U(K{)<br>
     *
     * @param arg Zbgl
     */
    public void setAttr9(final boolean arg) {
        fInput.setAttr9(arg);
        fIsFieldAttr9Processed = true;
    }

    /**
     * Ant^XN[attr9]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 9<br>
     * ^U(K{)<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getAttr9() {
        return fInput.getAttr9();
    }

    /**
     * Ant^XN[attr10]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 10<br>
     * blanco:boolean<br>
     *
     * @param arg Zbgl
     */
    public void setAttr10(final boolean arg) {
        fInput.setAttr10(arg);
        fIsFieldAttr10Processed = true;
    }

    /**
     * Ant^XN[attr10]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 10<br>
     * blanco:boolean<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getAttr10() {
        return fInput.getAttr10();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoAntTaskSampleTask begin.");

        // ڔԍ[1]AAgr[g[attr1]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr1Processed == false) {
            throw new BuildException("K{Agr[g[attr1]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[3]AAgr[g[attr3]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr3Processed == false) {
            throw new BuildException("K{Agr[g[attr3]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[5]AAgr[g[attr5]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr5Processed == false) {
            throw new BuildException("K{Agr[g[attr5]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[7]AAgr[g[attr7]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr7Processed == false) {
            throw new BuildException("K{Agr[g[attr7]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[9]AAgr[g[attr9]͕K{͂łB̓`FbNs܂B
        if (fIsFieldAttr9Processed == false) {
            throw new BuildException("K{Agr[g[attr9]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- attr1:[" + getAttr1() + "]");
            System.out.println("- attr2:[" + getAttr2() + "]");
            System.out.println("- attr3:[" + getAttr3() + "]");
            System.out.println("- attr4:[" + getAttr4() + "]");
            System.out.println("- attr5:[" + getAttr5() + "]");
            System.out.println("- attr6:[" + getAttr6() + "]");
            System.out.println("- attr7:[" + getAttr7() + "]");
            System.out.println("- attr8:[" + getAttr8() + "]");
            System.out.println("- attr9:[" + getAttr9() + "]");
            System.out.println("- attr10:[" + getAttr10() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoAntTaskSampleProcessC^tF[X blanco.sample.taskpbP[W BlancoAntTaskSampleProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoAntTaskSampleProcess proc = new BlancoAntTaskSampleProcessImpl();
            if (proc.execute(fInput) != BlancoAntTaskSampleBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
